bayespy.nodes.VaryingGaussianMarkovChain.broadcasting_multiplier
================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.broadcasting_multiplier